mod advertised_service;
mod automation_time;
mod bag_of_coins;
mod carved_coin;
mod charge;
mod charge_frequency;
mod commodity_category;
mod commodity_kind;
mod contract;
mod contract_metrics;
mod contract_status;
mod country;
mod decimal;
mod denomination;
mod digital_asset;
mod digital_service;
mod historic_activity;
mod historic_day;
mod historic_month;
mod invoice;
mod national_currency;
mod ownership;
mod rate_card;
mod wallet;
mod service_instance;
mod master_authority;
mod wallet_instance;
mod instance_command;
mod instance_hello;
mod instance_export;

pub use advertised_service::*;
pub use automation_time::*;
pub use bag_of_coins::*;
pub use carved_coin::*;
pub use charge::*;
pub use charge_frequency::*;
pub use commodity_category::*;
pub use commodity_kind::*;
pub use contract::*;
pub use contract_metrics::*;
pub use contract_status::*;
pub use country::*;
pub use decimal::*;
pub use denomination::*;
pub use digital_asset::*;
pub use digital_service::*;
pub use historic_activity::*;
pub use historic_day::*;
pub use historic_month::*;
pub use invoice::*;
pub use national_currency::*;
pub use ownership::*;
pub use rate_card::*;
pub use wallet::*;
pub use service_instance::*;
pub use master_authority::*;
pub use wallet_instance::*;
pub use instance_command::*;
pub use instance_hello::*;
pub use instance_export::*;

pub const WALLET_COLLECTION_ID: u64 = 2259995437953076879u64;
pub const CONTRACT_COLLECTION_ID: u64 = 8278931753731734656u64;
pub const INSTANCE_COLLECTION_ID: u64 = 5476918267819474034u64;
pub const INVOICE_COLLECTION_ID: u64 = 1234960345778345782u64;
pub const MASTER_AUTHORITY_ID: u64 = 12743381463764637636u64;
pub const INSTANCE_ROOT_ID: u64 = 9384758237459681256u64;

pub const COINS_PER_STACK_TO_BE_COMBINED: usize = 10usize;
